Coverage for audoma_api/migrations/0001_initial.py: 0%

1# Generated by Django 3.2.12 on 2022-04-21 12:41

2

3 from django.db import (

4 migrations,

5 models,

6)

7

8 import audoma.django.db.fields

9

10

11 class Migration(migrations.Migration):

12

13 initial = True

14

15 dependencies = []

16

17 operations = [

18 migrations.CreateModel(

19 name="ExampleFileModel",

20 fields=[

21 (

22 "id",

23 models.BigAutoField(

24 auto_created=True,

25 primary_key=True,

26 serialize=False,

27 verbose_name="ID",

28 ),

29 ),

30 ("file_field", models.FileField(upload_to="")),

31 ("name", audoma.django.db.fields.CharField(max_length=255)),

32 ],

33 ),

34 migrations.CreateModel(

35 name="ExampleModel",

36 fields=[

37 (

38 "id",

39 models.BigAutoField(

40 auto_created=True,

41 primary_key=True,

42 serialize=False,

43 verbose_name="ID",

44 ),

45 ),

46 ("char_field", audoma.django.db.fields.CharField(max_length=255)),

47 (

48 "phone_number",

49 audoma.django.db.fields.PhoneNumberField(

50 max_length=128, region=None

51 ),

52 ),

53 (

54 "phone_number_example",

55 audoma.django.db.fields.PhoneNumberField(

56 max_length=128, region=None

57 ),

58 ),

59 ("email", audoma.django.db.fields.EmailField(max_length=254)),

60 ("text_field", audoma.django.db.fields.TextField()),

61 ("url", audoma.django.db.fields.URLField()),

62 ("boolean", audoma.django.db.fields.BooleanField()),

63 ("nullboolean", audoma.django.db.fields.BooleanField(null=True)),

64 ("mac_adress", audoma.django.db.fields.MACAddressField(integer=True)),

65 ("slug", audoma.django.db.fields.SlugField()),

66 ("uuid", audoma.django.db.fields.UUIDField()),

67 ("ip_address", audoma.django.db.fields.GenericIPAddressField()),

68 ("integer", audoma.django.db.fields.IntegerField()),

69 ("_float", audoma.django.db.fields.FloatField()),

70 (

71 "decimal",

72 audoma.django.db.fields.DecimalField(

73 decimal_places=2, max_digits=10

74 ),

75 ),

76 ("datetime", audoma.django.db.fields.DateTimeField()),

77 ("date", audoma.django.db.fields.DateField()),

78 ("time", audoma.django.db.fields.TimeField()),

79 ("duration", audoma.django.db.fields.DurationField()),

80 (

81 "choices",

82 audoma.django.db.fields.IntegerField(

83 choices=[(1, "example 1"), (2, "example 2"), (3, "example 3")]

84 ),

85 ),

86 ("json", audoma.django.db.fields.JSONField(default=dict)),

87 (

88 "money_currency",

89 audoma.django.db.fields.CurrencyField(

90 choices=[("EUR", "Euro"), ("USD", "US Dollar")],

91 default="XYZ",

92 max_length=3,

93 ),

94 ),

95 (

96 "money",

97 audoma.django.db.fields.MoneyField(decimal_places=2, max_digits=10),

98 ),

99 ],

100 ),

101 migrations.CreateModel(

102 name="ExamplePerson",

103 fields=[

104 (

105 "id",

106 models.BigAutoField(

107 auto_created=True,

108 primary_key=True,

109 serialize=False,

110 verbose_name="ID",

111 ),

112 ),

113 ("first_name", audoma.django.db.fields.CharField(max_length=225)),

114 ("last_name", audoma.django.db.fields.CharField(max_length=255)),

115 ("age", audoma.django.db.fields.IntegerField()),

116 ("email", audoma.django.db.fields.EmailField(max_length=254)),

117 ("birth_country", audoma.django.db.fields.CharField(max_length=255)),

118 ("residence_city", audoma.django.db.fields.CharField(max_length=255)),

119 ("has_valid_account", audoma.django.db.fields.BooleanField()),

120 ("ip_address", audoma.django.db.fields.GenericIPAddressField()),

121 (

122 "savings_currency",

123 audoma.django.db.fields.CurrencyField(

124 choices=[("EUR", "Euro"), ("USD", "US Dollar")],

125 default="PLN",

126 max_length=3,

127 ),

128 ),

129 (

130 "savings",

131 audoma.django.db.fields.MoneyField(

132 decimal_places=2, default_currency="PLN", max_digits=14

133 ),

134 ),

135 (

136 "phone_number",

137 audoma.django.db.fields.PhoneNumberField(

138 max_length=128, region="IT"

139 ),

140 ),

141 ],

142 ),

143 ]